@@ -102,7 +102,7 @@ typedef uint16_t u_int16_t;
 
 // The following guarenty declaration of the byte swap functions, and
 // define __BYTE_ORDER for MSVC
-#if defined COMPILER_MSVC || defined WIN32
+#if defined COMPILER_MSVC || defined WIN32 || defined __WIN32__
 #include <stdlib.h>
 #define __BYTE_ORDER __LITTLE_ENDIAN
 #define bswap_16(x) _byteswap_ushort(x)
@@ -265,6 +265,8 @@ inline size_t strnlen(const char *s, size_t maxlen) {
   return maxlen;
 }
 
+using namespace std;  // just like VC++, we need a using here
+
 // Doesn't exist on OSX; used in google.cc for send() to mean "no flags".
 #define MSG_NOSIGNAL 0
 
@@ -694,11 +696,17 @@ extern inline void prefetch(const char *x) {}
 #include <assert.h>
 #include <windows.h>
 #undef ERROR
+#include "base/stl_decl.h"
+
+#include <float.h>  // for nextafter functionality on windows
+#include <math.h>  // for HUGE_VAL
 
 #ifndef HUGE_VALF
 #define HUGE_VALF (static_cast<float>(HUGE_VAL))
 #endif
 
+using namespace std;
+
 // VC++ doesn't understand "uint"
 #ifndef HAVE_UINT
 #define HAVE_UINT 1
@@ -908,6 +916,21 @@ struct PortableHashBase { };
 #define gethostbyname gethostbyname_is_not_thread_safe_DO_NOT_USE
 #endif
 
+// create macros in which the programmer should enclose all specializations
+// for hash_maps and hash_sets. This is necessary since these classes are not
+// STL standardized. Depending on the STL implementation they are in different
+// namespaces. Right now the right namespace is passed by the Makefile
+// Examples: gcc3: -DHASH_NAMESPACE=__gnu_cxx
+//           icc:  -DHASH_NAMESPACE=std
+//           gcc2: empty
+
+#ifndef HASH_NAMESPACE
+#  define HASH_NAMESPACE_DECLARATION_START
+#  define HASH_NAMESPACE_DECLARATION_END
+#else
+#  define HASH_NAMESPACE_DECLARATION_START  namespace HASH_NAMESPACE {
+#  define HASH_NAMESPACE_DECLARATION_END    }
+#endif
 
 // Our STL-like classes use __STD.
 #if defined(COMPILER_GCC3) || defined(COMPILER_ICC) || defined(__APPLE__) || defined(COMPILER_MSVC)
